@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sgml-validator.c,v 1.10 2004/02/24 17:51:56 chpe Exp $
+ *  $Id: sgml-validator.c,v 1.10.2.1 2004/06/10 01:30:30 adamh Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -436,10 +436,11 @@ free_sgml_validator_append_cb_data (gpointer data)
 static gboolean
 sgml_validator_append_internal (gpointer data)
 {
+	SgmlValidatorAppendCBData *append_data;
+
 	g_return_if_fail (data != NULL);
 
-	SgmlValidatorAppendCBData *append_data =
-		(SgmlValidatorAppendCBData *) data;
+	append_data = (SgmlValidatorAppendCBData *) data;
 
 	error_viewer_append (append_data->validator->priv->error_viewer,
 			     append_data->error_type,
