@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.8 2004/02/24 17:47:18 chpe Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.8.2.1 2004/04/19 20:03:49 adamh Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -316,17 +316,17 @@ dom_mouse_down_cb (EphyEmbed *embed,
             !(context & EMBED_CONTEXT_INPUT))
 	{
 		EphyGesture *gesture;
-		EphyWindow *window;
+		GtkWidget *toplevel;
 		EphyTab *tab;
 		guint x, y;
 
 		tab = ephy_tab_for_embed (embed);
 		g_return_if_fail (EPHY_IS_TAB (tab));
 
-		window = ephy_tab_get_window (tab);
-		g_return_if_fail (EPHY_IS_WINDOW (window));
+		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (tab));
+		g_return_if_fail (toplevel != NULL);
 
-		gesture = ephy_gesture_new (GTK_WIDGET (window), event);
+		gesture = ephy_gesture_new (toplevel, event);
 
 		g_signal_connect (gesture, "gesture-performed",
 				  G_CALLBACK (gesture_performed_cb),
