@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sample2-extension.c,v 1.3 2004/02/24 17:47:23 chpe Exp $
+ *  $Id: ephy-sample2-extension.c,v 1.3.2.1 2004/05/30 12:22:29 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -111,7 +111,7 @@ ephy_sample2_extension_finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static void
+static gboolean
 dom_mouse_down_cb (EphyEmbed *embed,
 		   EphyEmbedEvent *event,
 		   EphySample2Extension *extension)
@@ -122,6 +122,8 @@ dom_mouse_down_cb (EphyEmbed *embed,
 	LOG ("DOM Event %p", dom_event)
 
 	mozilla_do_something (dom_event);
+
+	return FALSE;
 }
 
 static void
